package com.altinity.opsview.odw.elements;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

import java.text.DecimalFormat;

import org.dom4j.Element;

import com.altinity.opsview.odw.ReportConstants;
import com.altinity.opsview.odw.bc.ODWReportLogger;
import com.altinity.opsview.odw.dao.ODWReportConfigDAO;
import com.altinity.opsview.odw.dao.ODWReportDAO;
import com.altinity.opsview.odw.exception.ReportException;
import com.altinity.opsview.odw.model.AvailabilityModel;
import com.altinity.opsview.odw.reports.ReportCriteria;

/**
 * @author Administrator Calculates the average Availibility over the reporting
 *         period over all host groups.
 */
public class AvailabilityOverview extends AbstractReportElement implements ReportConstants {
	
	private AvailabilityModel am;

	/**
	 *
	 */
	public AvailabilityOverview(ReportCriteria rc, ODWReportDAO dao, ODWReportConfigDAO configDao, ODWReportLogger log) {
		super(rc, dao, configDao, log);
	}

	/**
	 *
	 */
	public Element addElement(Element elements) {
		
		DecimalFormat percentFormat = new DecimalFormat(PERCENT_FORMAT);
		
		Element availabilityOverview = elements.addElement("element");
		availabilityOverview.addElement("title").setText("Average Availability Over Reporting Period");
		availabilityOverview.addAttribute("name", "availabilityOverview");
		
		// Handle case where data has been found
		if ( am.isValid() ) {
					
			availabilityOverview.addElement("availibility").setText(percentFormat.format(am.getAverageAvailablility()));
			availabilityOverview.addElement("scheduled-downtime").setText(percentFormat.format(am.getScheduledDowntime()));
			availabilityOverview.addElement("unscheduled-downtime").setText(
					percentFormat.format(am.getUnscheduledDowntime()));
		}
		// Otherwise no data has been found
		else {
			
			// Add empty element
			availabilityOverview.addElement("empty").setText("true");
			
			// Report error
			log.getErrors().add("No data found for module 'Average Availability Over Reporting Period'");
		}
		
		return availabilityOverview;
	}
	
	/**
	 * 
	 */
	public void runQuery() throws ReportException {
		
		am = dao.getOverallAvailability(configDao, rc);
	}
}
