package com.altinity.opsview.odw.model;

import java.util.ArrayList;
import java.util.List;

import com.excira.utils.StringUtils;

/**
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

public class ServiceCheckGroup {

	// This class represents a group of identical servicechecks
	// Servicechecks are identical if they have the same hostname and name
	
	private List <Integer> scIds = new ArrayList<Integer>();
	private String text;
	private String hostName;
	private String name;
	private boolean nullOrEmptyDescription;
	
	/**
	 * 
	 */
	public void setServiceChecks(List <ServiceCheck> serviceChecks) {
		
		for ( ServiceCheck sc : serviceChecks ) 
			addServiceCheck(sc);
	}
	
	/**
	 * 
	 */
	public void addServiceCheck(ServiceCheck serviceCheck) {
		
		// Add servicecheck ID to list if 
		// it has not already been added
		int id = serviceCheck.getId();
		if ( !scIds.contains(id) )
			scIds.add(id);
		
		// Now check if this is the most recent service check
		// If so, set the text for this service check group
		if ( serviceCheck.isMostRecent() ) {
			text = serviceCheck.getDescription();
			nullOrEmptyDescription = StringUtils.isNullOrEmptyString(serviceCheck.getDescription());
			hostName = serviceCheck.getHostName();
			name = serviceCheck.getName();
		}
	}
	
	/**
	 * 
	 */
	public List<Integer> getIds() {
		return scIds;
	}
	
	/**
	 * 
	 */
	public String getText() {
		return text;
	}
	
	/**
	 * 
	 */
	public void setText(String text) {
		
		this.text = text;
	}
	
	/**
	 * 
	 */
	public boolean hasMostRecent() {
		
		return StringUtils.notNullOrEmpty(text);
	}
	
	/**
	 * 
	 */
	public String getHostName() {
		
		return hostName;
	}
	
	/**
	 * 
	 */
	public String getName() {
		
		return name;
	}
	
	/**
	 * 
	 */
	public String toString() {
		
		StringBuffer toString = new StringBuffer();
		toString.append(text);
		toString.append("\n");
		
		return toString.toString();
	}
	
	/**
	 * 
	 */
	public boolean hasNullOrEmptyDescription() {
		
		return nullOrEmptyDescription;
	}
	
	/**
	 * 
	 */
	public String getKey() {
		
		return name + hostName;
	}
}
