package com.altinity.opsview.odw.reports;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

import java.text.SimpleDateFormat;
import java.util.Date;

import com.altinity.opsview.odw.exception.ReportException;
import com.excira.utils.StringUtils;

public class ReportCriteria {
	
	private int reportId = 0;
	private Date reportStartDate;
	private Date dataStartDate;
	private	Date reportEndDate;
	private Date dataEndDate;
	private	String dayIntervalStart = "00:00:00";
	private	String dayIntervalEnd = "23:59:59";
	private	String reportName="";
	private	String reportType="";
	private	String reportSelection="";
	private	String fileFormat="";
	private	String chartsRoot="";
	private String hostGroup;
	private String format;
	
	private String label;
	private final String LABEL_HOSTNAME_SERVICECHECK = "hostname/servicecheck";
	private final String LABEL_SERVICECHECK = "servicecheck";
	private final String LABEL_DESCRIPTION = "description";
	private int startOfWeek;
	private int reportTypeId;
	
	/**
	 *
	 */
	public ReportCriteria() {
		
	}
	
	/**
	 * Copy Constructor
	 */
	public ReportCriteria(ReportCriteria rc) {
		
		reportId = rc.reportId;
		reportStartDate = rc.reportStartDate;
		reportEndDate = rc.reportEndDate;
		dataStartDate = rc.dataStartDate;
		dataEndDate = rc.dataEndDate;
		dayIntervalStart = rc.dayIntervalStart;
		dayIntervalEnd = rc.dayIntervalEnd;
		reportName = rc.reportName;
		reportType = rc.reportType;
		reportSelection = rc.reportSelection;
		fileFormat = rc.fileFormat;
		chartsRoot = rc.chartsRoot;
		
		label = rc.label;
		startOfWeek = rc.startOfWeek;
		reportTypeId = rc.reportTypeId;
	}
	
	/**
	 *
	 */
	public String getDayIntervalEnd() {
		return dayIntervalEnd;
	}
		
	/**
	 *
	 */
	public void setDayIntervalEnd(String dayIntervalEnd) {
		this.dayIntervalEnd = dayIntervalEnd;
	}
	
	/**
	 *
	 */	
	public String getDayIntervalStart() {
		return dayIntervalStart;
	}
	
	/**
	 *
	 */	
	public void setDayIntervalStart(String dayIntervalStart) {
		this.dayIntervalStart = dayIntervalStart;
	}
	
	/**
	 *
	 */	
	public Date getReportEndDate() {
		return reportEndDate;
	}
	
	/**
	 *
	 */	
	public void setReportEndDate(Date endDate) {
		this.reportEndDate = endDate;
	}
	
	/**
	 *
	 */	
	public int getReportId() {
		return reportId;
	}
	
	/**
	 *
	 */	
	public void setReportId(int reportId) {
		this.reportId = reportId;
	}
	
	/**
	 *
	 */	
	public Date getReportStartDate() {
		return reportStartDate;
	}
	
	/**
	 *
	 */	
	public String getReportStartDateString() {
		return new SimpleDateFormat("yyyy-MM-dd").format(reportStartDate) + " 00:00:00";
	}
	
	/**
	 *
	 */	
	public String getReportEndDateString() {
		return new SimpleDateFormat("yyyy-MM-dd").format(reportEndDate) + " 23:59:59";
	}
	
	/**
	 *
	 */	
	public void setReportStartDate(Date startDate) {
		this.reportStartDate = startDate;
	}
	
	/**
	 *
	 */
	public String getReportName() {
		return reportName;
	}
	
	/**
	 *
	 */
	public void setReportName(String reportTitle) {
		this.reportName = reportTitle;
	}
	
	/**
	 *
	 */
	public String getReportType() {
		return reportType;
	}
	
	/**
	 *
	 */
	public void setReportType(String reportType) {
		this.reportType = reportType;
	}
	
	/**
	 *
	 */
	public String getReportSelection() {
		return reportSelection;
	}

	/**
	 *
	 */
	public void setReportSelection(String reportSelection) {
		this.reportSelection = reportSelection;
	}
	
	/**
	 *
	 */
	public String getChartsRoot() {
		return chartsRoot;
	}
	
	/**
	 *
	 */
	public void setChartsRoot(String chartsRoot) {
		this.chartsRoot = chartsRoot;
	}
	
	/**
	 *
	 */
	public String getFileFormat() {
		return fileFormat;
	}



	public void setFileFormat(String fileFormat) {
		this.fileFormat = fileFormat;
	}

	/**
	 * 
	 */
	public String getHostGroup() {
		return hostGroup;
	}

	/**
	 * 
	 */
	public void setHostGroup(String hostGroup) {
		this.hostGroup = hostGroup;
	}

	/**
	 * 
	 */
	public Date getDataStartDate() {
		return dataStartDate;
	}

	/**
	 * 
	 */
	public void setDataStartDate(Date dataStartDate) {
		this.dataStartDate = dataStartDate;
	}

	/**
	 * 
	 */
	public Date getDataEndDate() {
		return dataEndDate;
	}
	
	/**
	 * 
	 */
	public void setDataEndDate(Date dataEndDate) {

		this.dataEndDate = dataEndDate;
	}
	
	/**
	 * 
	 */
	public String getFormat() {
		return format;
	}
	
	/**
	 * 
	 */
	public void setFormat(String format) throws ReportException {
		
		if ( !format.equals("US") && !format.equals("A4") )  {
			
			this.format = "A4";
			throw new ReportException("Unrecognized report format '" + format + "'. Using default format (A4).");
		}
		else
			this.format = format;
	}
	
	/**
	 * 
	 */
	public String getLabel() {
		return label;
	}
	
	/**
	 * 
	 */
	public void setLabel(String label) throws ReportException {
		
		if ( StringUtils.notNullOrEmpty(label) &&
				!label.equals(LABEL_DESCRIPTION) && 
				!label.equals(LABEL_HOSTNAME_SERVICECHECK) &&
				!label.equals(LABEL_SERVICECHECK) )
			throw new ReportException("Unrecognized report loabel '" + label + "'. Using default label (hostname/servicecheck).");
		
		this.label = label;
	}
	
	/**
	 * 
	 */
	public boolean isUseHostNameServiceCheckLabel() {
		
		return LABEL_HOSTNAME_SERVICECHECK.equals(label);
	}
	
	/**
	 * 
	 */
	public boolean isUseServiceCheckLabel() {
		
		return LABEL_SERVICECHECK.equals(label);
	}
	
	/**
	 * 
	 */
	public boolean isUseDescriptionLabel() {
		
		return LABEL_DESCRIPTION.equals(label);
	}
	
	/**
	 * 
	 */
	public int getStartOfWeek() {
		return startOfWeek;
	}
	
	/**
	 * 
	 */
	public void setStartOfWeek(int startOfWeek) {
		this.startOfWeek = startOfWeek;
	}
	
	/**
	 * 
	 */
	public int getReportTypeId() {
		return reportTypeId;
	}
	
	/**
	 * 
	 */
	public void setReportTypeId(int typeId) {
		this.reportTypeId = typeId;
	}
}
