package com.altinity.opsview.odw.reports;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.excira.jfreechart.BarData;
import com.excira.jfreechart.XYPoint;



public class ReportUtils {
	
	public static String X_INDEX = "xIndex";
	public static String Y_INDEX = "yIndex";
	public static String ANNOTATION_INDEX = "annotationIndex";
	
	public static String PERCENT_OK_INDEX = "percentOK";
	public static String PERCENT_SCHED_INDEX = "percentSched";
	public static String PERCENT_UNSCHED_INDEX = "percentUnsched";
	public static String DATE_INDEX = "date";
	
	public static List generateXYPoints(Map indices, ResultSet resultSet) {
		
		List <XYPoint> points = new ArrayList<XYPoint>();
		
		try {
		
			while ( resultSet.next() ) {
				
				// Get date
				Date x = resultSet.getDate(((Integer)indices.get(X_INDEX)).intValue());
				
				// Get value
				double y = resultSet.getDouble(((Integer)indices.get(Y_INDEX)).intValue()) * 100;
				
				// Check if annotation exists and
				// create xy point accordingly
				XYPoint xyPoint = null;
				if ( indices.containsKey(ANNOTATION_INDEX) ) {
					String annotation = resultSet.getString(((Integer)indices.get(ANNOTATION_INDEX)).intValue());
					xyPoint = new XYPoint(x, y, annotation);
				}
				else {
					xyPoint = new XYPoint(x, y);
				}
				points.add(xyPoint);
			}
		}
		catch(Exception e) {
			
			System.out.println("Error in ReportUtils.generateXYPoints()");
			e.printStackTrace();
		}
		
		return points;
	}
	
	/**
	 * value = percentOK, percentSched, percentUnsched
	 * rowKey = "percentOK", "percentSched", "percentUnsched"
	 * columnKey = 07/07/2006, 08/07/2006, 09/07/2006
	 */
	public static List generateBarData(ResultSet resultSet) {
		
		List barDataValues = new ArrayList();
		
		try {
		
			while ( resultSet.next() ) {
				
				// Get date
				Comparable date = resultSet.getDate(1);
				
				// Create percentOK
				double percentage = resultSet.getDouble(2) * 100;
				Comparable type = PERCENT_OK_INDEX;
				BarData data = new BarData(percentage, type, date);
				barDataValues.add(data);
				
				// Create percentSched
				percentage = resultSet.getDouble(3) * 100;
				type = PERCENT_SCHED_INDEX;
				data = new BarData(percentage, type, date);
				barDataValues.add(data);
				
				// Create percentUnsched
				percentage = resultSet.getDouble(4) * 100;
				type = PERCENT_UNSCHED_INDEX;
				data = new BarData(percentage, type, date);
				barDataValues.add(data);				
			}
		}
		catch(Exception e) {
			
			System.out.println("Error in ReportUtils.generateXYPoints()");
			e.printStackTrace();
		}
		
		return barDataValues;
	}
	
	/**
	 * 
	 */
	public static Map generateParamMap(ResultSet resultSet) {
		
		Map params = new HashMap();
		
		try {
		
			int total = 0;
			double percentOK = 0.0d;
			double percentSched = 0.0d;
			double percentUnsched = 0.0d;
			
			while ( resultSet.next() ) {
								
				// Get percentOK and add to total
				percentOK = percentOK + resultSet.getDouble(1);

				// Get percentSched and add to total
				percentSched = percentSched + resultSet.getDouble(2);

				// Get percentUnsched and add to total
				percentUnsched = percentUnsched + resultSet.getDouble(3);				
				
				// Incrememt total number of rows
				total++;
			}
			
			// Calculate averages and add to map
			percentOK = (percentOK / total) * 100;
			params.put("averagePercentOK", new Double(percentOK));
			
			percentSched = (percentSched / total) * 100;
			params.put("averagePercentSched", new Double(percentSched));
			
			percentUnsched = (percentUnsched / total) * 100;
			params.put("averagePercentUnsched", new Double(percentUnsched));
		}
		catch(Exception e) {
			
			System.out.println("Error in ReportUtils.generateXYPoints()");
			e.printStackTrace();
		}
		
		return params;
	}

}
