package com.excira.jfreechart;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Paint;
import java.awt.Stroke;
import java.awt.geom.Ellipse2D;
import java.awt.geom.Line2D;
import java.awt.geom.Rectangle2D;

import org.jfree.ui.Drawable;

public class CircleDrawer implements Drawable {

	  /** The outline paint. */
   private Paint outlinePaint;

   /** The outline stroke. */
   private Stroke outlineStroke;

   /** The fill paint. */
   private Paint fillPaint;

   /**
    * Creates a new instance.
    * 
    * @param outlinePaint  the outline paint.
    * @param outlineStroke  the outline stroke.
    * @param fillPaint  the fill paint.
    */
   public CircleDrawer(final Paint outlinePaint, 
                       final Stroke outlineStroke, 
                       final Paint fillPaint) {
       this.outlinePaint = outlinePaint;
       this.outlineStroke = outlineStroke;
       this.fillPaint = fillPaint;
   }

   /**
    * Draws the circle.
    * 
    * @param g2  the graphics device.
    * @param area  the area in which to draw.
    */
   public void draw(final Graphics2D g2, final Rectangle2D area) {
       final Ellipse2D ellipse = new Ellipse2D.Double(area.getX(), area.getY(),
                                                area.getWidth(), area.getHeight());
       if (this.fillPaint != null) {
           g2.setPaint(this.fillPaint);
           g2.fill(ellipse);
       }
       if (this.outlinePaint != null && this.outlineStroke != null) {
           g2.setPaint(this.outlinePaint);
           g2.setStroke(this.outlineStroke);
           g2.draw(ellipse);
       }

       g2.setPaint(Color.black);
       g2.setStroke(new BasicStroke(1.0f));
       final Line2D line1 = new Line2D.Double(area.getCenterX(), area.getMinY(),
                                        area.getCenterX(), area.getMaxY());
       final Line2D line2 = new Line2D.Double(area.getMinX(), area.getCenterY(),
                                        area.getMaxX(), area.getCenterY());
       g2.draw(line1);
       g2.draw(line2);
   }

}
